@@ -10,8 +10,9 @@ use IO::Socket;
 use IO::Socket::SSL;
 use Time::Crontab;
 use Date::Format 'time2str';
+use Encode 'encode';
 
-our $VERSION = '1.11'; # VERSION
+our $VERSION = '1.12'; # VERSION
 
 sub new {
     my $class = shift;
@@ -73,7 +74,7 @@ sub run {
 sub note {
     my ( $self, $msg, $err ) = @_;
     chomp($msg);
-    $msg = '[' . time2str( '%d/%b/%Y:%H:%M:%S %z', time() ) . '] ' . $msg . "\n";
+    $msg = '[' . time2str( '%d/%b/%Y:%H:%M:%S %z', time() ) . '] ' . encode( 'utf-8' => $msg ) . "\n";
 
     if ($err) {
         die $msg if ( $err eq 'die' );
@@ -278,11 +279,19 @@ sub _on_message {
                 $captured_matches = { %$captured_matches, %+ } if ( keys %+ );
             }
 
-            last if ( $hook->{code}->(
-                $self,
-                { %{ $self->{in} } },
-                $captured_matches,
-            ) );
+            my $rv;
+            eval {
+                $rv = $hook->{code}->(
+                    $self,
+                    { %{ $self->{in} } },
+                    $captured_matches,
+                );
+            };
+            if ($@) {
+                warn "$@\n";
+            }
+
+            last if ($rv);
         }
     }
 }
@@ -418,6 +427,17 @@ sub register {
     return $self;
 }
 
+sub vars {
+    my ( $self, $name ) = @_;
+    ( $name = lc( substr( ( caller() )[0], length(__PACKAGE__) + 2 ) ) ) =~ s/::/\-/g unless ($name);
+    return $self->{vars}{$name};
+}
+
+sub settings {
+    my ( $self, $name ) = @_;
+    return ( defined $name ) ? $self->{$name} : { %$self };
+}
+
 sub reply {
     my ( $self, $message ) = @_;
 
@@ -448,8 +468,9 @@ sub say {
     my $self = shift;
 
     for (@_) {
-        $self->{socket}->print( $_ . "\r\n" );
-        $self->note("<<< $_");
+        my $string = encode( 'utf-8' => $_ );
+        $self->{socket}->print( $string . "\r\n" );
+        $self->note("<<< $string");
     }
     return $self;
 }
@@ -532,7 +553,7 @@ Bot::IRC - Yet Another IRC Bot
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bot-IRC.svg)](https://travis-ci.org/gryphonshafer/Bot-IRC)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bot-IRC/badge.png)](https://coveralls.io/r/gryphonshafer/Bot-IRC)
@@ -989,6 +1010,39 @@ namespace) that you want to skip.
 
 Note that this will not block the reloading of plugins with C<reload()>.
 
+=head2 vars
+
+When you are within a plugin, you can call C<vars()> to get the variables for
+the plugin by it's lower-case "simplified" name, which is the plugin's class
+name all lower-case, without the preceding "Bot::IRC::" bit, and with "::"s
+replaced with dashes. For example, let's say you were writing a
+"Bot::IRC::X::Something" plugin. You would have users set variables in their
+instantiation like so:
+
+    Bot::IRC->new
+        plugins => ['Something'],
+        vars    => { x-something => { answer => 42 } },
+    )->run;
+
+Then from within the "Bot::IRC::X::Something" plugin, you would access these
+variables like so:
+
+    my $my_vars = $bot->vars;
+    say 'The answer to life, the universe, and everything is ' . $my_vars->{answer};
+
+If you want to access the variables for a different namespace, pass into
+C<vars()> the "simplified" name you want to access.
+
+    my $my_other_vars = $bot->vars('x-something-else');
+
+=head2 settings
+
+If you need access to the bot's settings, you can do so with C<settings()>.
+Supply the setting name/key to get that setting, or provide no name/key to get
+all settings as a hashref.
+
+    my $connection_settings_hashref = $bot->settings('connect');
+
 =head1 INLINE PLUGINS
 
 You can optionally inject inline plugins by providing them as hashref. This
