@@ -7,11 +7,11 @@ use warnings;
 use DateTime;
 use DateTime::Format::Human::Duration;
 
-our $VERSION = '1.11'; # VERSION
+our $VERSION = '1.12'; # VERSION
 
 sub init {
     my ($bot) = @_;
-    my $greeting = $bot->{vars}{greeting} // 'greetings';
+    my $greeting = $bot->vars // 'greetings';
 
     $bot->hook(
         {
@@ -79,7 +79,7 @@ Bot::IRC::Greeting - Bot::IRC greet joining users to channels
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =head1 SYNOPSIS
 
