@@ -7,7 +7,7 @@ use warnings;
 use DateTime;
 use DateTime::Format::Human::Duration;
 
-our $VERSION = '1.11'; # VERSION
+our $VERSION = '1.12'; # VERSION
 
 sub init {
     my ($bot) = @_;
@@ -117,7 +117,7 @@ sub init {
 
     $bot->helps( infobot =>
         'Mimics the factoid functionality of the classic infobot. ' .
-        'Usage: https://metacpan.org/pod/Bot::IRC::Infobot.'
+        'Usage: https://metacpan.org/pod/Bot::IRC::Infobot'
     );
 }
 
@@ -135,7 +135,7 @@ Bot::IRC::Infobot - Bot::IRC add classic "infobot" functionality to the bot
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =head1 SYNOPSIS
 
