@@ -4,7 +4,7 @@ package Bot::IRC::Join;
 use strict;
 use warnings;
 
-our $VERSION = '1.11'; # VERSION
+our $VERSION = '1.12'; # VERSION
 
 sub init {
     my ($bot) = @_;
@@ -81,10 +81,9 @@ sub init {
             my %channels = map { $_ => 1 } @{ $bot->store->get('channels') || [] };
             @channels    = keys %channels unless (@channels);
 
-            if ( not @channels and $bot->{connect}{join} ) {
-                @channels = ( ref $bot->{connect}{join} eq 'ARRAY' )
-                    ? @{ $bot->{connect}{join} }
-                    : $bot->{connect}{join}
+            my $join = $bot->settings('connect')->{join};
+            if ( not @channels and $join ) {
+                @channels = ( ref $join eq 'ARRAY' ) ? @$join : $join
             }
 
             $bot->join_super(@channels);
@@ -98,7 +97,7 @@ sub init {
 
     $bot->subs(
         part => sub {
-            my $bot    = shift;
+            my $bot      = shift;
             my %channels = map { $_ => 1 } @{ $bot->store->get('channels') || [] };
 
             $bot->part_super(@_);
@@ -109,6 +108,12 @@ sub init {
             return $bot;
         },
     );
+
+    $bot->subs(
+        channels => sub {
+            return shift->store->get('channels') || [];
+        },
+    );
 }
 
 1;
@@ -125,7 +130,7 @@ Bot::IRC::Join - Bot::IRC join and part channels and remember channels state
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =head1 SYNOPSIS
 
