@@ -8,7 +8,7 @@ use DBI;
 use DBD::SQLite;
 use JSON::XS;
 
-our $VERSION = '1.11'; # VERSION
+our $VERSION = '1.12'; # VERSION
 
 sub init {
     my ($bot) = @_;
@@ -22,7 +22,7 @@ sub new {
     my ( $class, $bot ) = @_;
     my $self = bless( {}, $class );
 
-    $self->{file} = $bot->{vars}{store} || 'store.sqlite';
+    $self->{file} = $bot->vars('store') || 'store.sqlite';
     my $pre_exists = ( -f $self->{file} ) ? 1 : 0;
 
     $self->{dbh} = DBI->connect( 'dbi:SQLite:dbname=' . $self->{file} ) or die "$@\n";
@@ -88,7 +88,7 @@ Bot::IRC::Store::SQLite - Bot::IRC persistent data storage with SQLite
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =head1 SYNOPSIS
 
